@@ -282,6 +282,12 @@ conventions of:
 
 The default output filename is: port_info_out.csv
 
+=head1 BUG REPORTS
+
+Please submit any bugs to:
+L<http://sourceforge.net/tracker/?group_id=97509&atid=618345>
+
+
 =head1 SEE ALSO
 
 L<Nmap::Parser::XML>
